Se även Hund.

Wikipedia har en artikel om:
hund

## Svenska[redigera]

### Substantiv[redigera]

Böjningar av hund | Singular | Plural
--- | --- | ---
utrum | Obestämd | Bestämd | Obestämd | Bestämd
Nominativ | hund | hunden | hundar | hundarna
Genitiv | hunds | hundens | hundars | hundarnas

en hund, i detta fall en beagle

hund

- uttal: "en hund" hɵndⓘ

1. en underart (Canis lupus familiaris) till arten varg (Canis lupus) inom däggdjursfamiljen hunddjur (Canidae); individ av underarten hund
     Går du ut med hunden?
     Synonymer: Canis familiaris (äldre klassificering), Canis familiaris domesticus (äldre klassificering); jycke (slang), vovve (barnspråk), byracka (nedsättande), hundracka (nedsättande), hundskrälle (nedsättande)
     Hyponymer: blodhund, draghund, fågelhund, fårhund, grythund, jakthund, kamphund, knarkhund, knähund, krigshund, ledarhund, narkotikahund, polishund, rashund, slädhund, spannhund, spårhund, sällskapshund, vakthund, vallhund, vinthund
     Sammansättningar: blodhund, fähund, hundarbete, hundbär, hunddag, hundfila, hundfloka, hundsfott, hundfästing, hundgalenskap, hundgläfs, hundgård, hundgöra, hundhus, hundhål, hundkedja, hundkex, hundkoja, hundkoppel, hundkäx, hundköp, hundland, hundlav, hundliv, hundloka, hundlopp, hundlus, hundlök, hundmusik, hundnappa, hundnappare, hundnappning, hundpenning, hundpromenad, hundracka, hundras, hundraseri, hundsjuka, hundskall, hundskatt, hundskrälle, hundsläde, hundsnus, hundstjärnan, hundsyssla, hundtass, hundtunga, hundturk, hundväder, hundvakt, hundvakten, hundven, hundväder, hundvän, hundända, hundäxing, hundöga, hundöra, lathund, mårdhund, rymdhund
     Fraser: (idiom) bära hundhuvudet för en annan, Det är svårt att lära gamla hundar att sitta., här ligger en hund begraven, Man ska inte döma hunden efter håren., Skällande hund bits inte., som hund och katt, otrogen hund, Hunden är människans bästa vän., stående hund
2. (nedsättande, överfört) skymford för föraktliga personer
     Sammansättningar: fyllhund, fähund, sathund, svinhund

  Besläktade ord: hundaktig, hundan, hundfatt, hundsk, hynda
  Se även tesaurus: Djur

#### Översättningar[redigera]

Canis lupus familiaris

- acehnesiska: asèë
- afrikaans: hond (af)
- albanska: qen (sq)
- alemanniska: Huushund
- arabiska: كَلْب (ar) m (kalb)
- baskiska: txakur (eu), or (eu)
- belarusiska: сабака (be) f
- bokmål: hund (no) m, tispe (no) f, bikkje (no) f
- bosniska: pas m
- bulgariska: куче (bg)
- burmesiska: ခွေး (my) (hkwe:)
- danska: hund (da)
- engelska: (♂ ♀) dog (en), (♂) dog (en), (♂ ♀) hound (en), (♀) bitch (en), (♂ ♀) pup (en), (♂ ♀) whelp (en)
- esperanto: hundo (eo), virhundo neologism ♂, hundiĉo neologism ♂, (♀) hundino (eo), hundido (eo) avkomma, (♂ avkomma) virhundido, (neologism ♂ avkomma) hundidiĉo, (♀ avkomma) hundidino
- estniska: koer (et)
- fang: mvú
- finsk romani: džuklo m, džukli f, juklo m, jukli f
- finska: koira (fi)
- franska: (♂ ♀) chien (fr) m, (♀) chienne (fr) f, (♂ ♀ avkomma) chiot (fr) m
- frisiska: hûn (fy)
- färöiska: hundur (fo) m
- grekiska: σκύλος (el) m (skílos), κύων (el) m (kíon), σκύλα (el) f (skíla), σκυλί (el) n (skilí)
- grönländska: qimmeq (kl)
- hebreiska: כלב (he) m (kélev), כֶּלֶב (he) m (kélev), כלבה f (kalbá), כַּלְבָּה f (kalbá)
- ido: (♂ ♀) hundo (io), (♂) hundulo (io), (♀) hundino (io), (♂ ♀ avkomma) hundyuno (io), (♂ avkomma) hundyunulo, (♀ avkomma) hundyunino
- indonesiska: anjing (id)
- isländska: hundur (is) m
- italienska: (♂ ♀) cane (it) m, (♂) cagna (it) f, (diminutiv; ♂ avkomma) cagnetto (it) m, (diminutiv; ♀ avkomma) cagnetta (it) f, (diminutiv; ♂ avkomma) cagnolino (it) m, (diminutiv; ♀ avkomma) cagnolina (it) f
- japanska: 犬 (ja) (いぬ (ja) (inu))
- jiddisch: הונט (yi) m (hunt), הינט (yi) pl (hint)
- kasjubiska: pies
- katalanska: gos (ca)
- khmer: ឆ្កែ (km) (chkae)
- kinesiska: 狗 (zh) (gǒu)
- kurdiska: se (ku), kûç (ku), kûçik (ku)
- lakota: šúŋka
- latin: canis (la) m
- limburgiska: hóndj (li)
- lulesamiska: bena
- luxemburgiska: Hond (lb)
- malajiska: anjing (ms), anjing-anjing pl
- nederländska: hond (nl) m
- nordsamiska: beana
- nynorska: hund (nn) m, tispe f, bikkje f
- persiska: سگ (fa) (sag)
- polska: pies (pl) m
- portugisiska: cão (pt) m, cadela (pt) f; (vardagligt) cachorro (pt) m, cachorra (pt) f
- ryska: (♂ ♀) собака (ru) f (sobáka), (♂ ♀) пёс (ru) m (pjos), (♂) пёс (ru) m (pjos), (♀) сука (ru) f (súka), (vardagligt ♂ ♀) псина (ru) f (psína)
- slovakiska: pes (sk) m
- somaliska: ey
- spanska: perro (es) m, perra (es) f
- svensk romani: jukklo u
- sydsamiska: bïenje
- tahitiska: ʻuri
- thai: หมา (th) (mǎa), สุนัข (th) (sù-nák)
- tibetanska: ཁྱི
- tjeckiska: pes (cs) m
- turkiska: köpek (tr)
- tyska: (♂ ♀) Hund (de) m
- ukrainska: собака (uk) m (sobáka), пес (uk) m (pes)
- umesamiska: biädnja
- ungerska: kutya (hu)
- urdu: کتا (ur) m (kuttā)
- vallonska: tchén (wa)
- vepsiska: koir
- vilamoviska: hund
- volapük: (♂ ♀) dog (vo), (♂) hidog (vo), (♀) jidog (vo), (♂ ♀ avkomma) dogül (vo), (♂ avkomma) hidogül, (♀ avkomma) jidogül

## Bokmål[redigera]

### Substantiv[redigera]

Böjningar av hund | Singular | Plural
--- | --- | ---
maskulinum | Obestämd | Bestämd | Obestämd | Bestämd
Nominativ | hund | hunden | hunder | hundene
Genitiv | hunds | hundens | hunders | hundenes

hund m

1. hund

## Danska[redigera]

### Substantiv[redigera]

Böjningar av hund | Singular | Plural
--- | --- | ---
utrum | Obestämd | Bestämd | Obestämd | Bestämd
Nominativ | hund | hunden | hunde | hundene
Genitiv | hunds | hundens | hundes | hundenes

hund u

1. hund
     Går du tur med hunden?
       Tar du en sväng med hunden?
     Hyponymer: tæve, hvalp, køter, tæppetisser, vovse, vovhund
     Besläktade ord: hundsk
     Sammansättningar: hundebid, hundehale, hundehalsbånd, hundehår, hundekennel, hundekiks, hundekurv, hundelort, hundemad, hundeven, blodhund, familiehund, gravhund, hanhund, hunhund, jagthund, muskelhund, racehund, slædehund, vagthund
     Fraser: flyvende hund, røde hunde, vittig hund, dér ligger hunden begravet, gå i hundene, man kan ikke lære en gammel hund nye kunster, man skal ikke skue hunden på hårene, som hund og kat, være en hund efter noget
2. (slang) hundring

## Fornfrisiska[redigera]

### Substantiv[redigera]

hund m

1. hund

## Fornnordiska[redigera]

### Substantiv[redigera]

hund

1. böjningsform av hundr

## Färöiska[redigera]

### Substantiv[redigera]

hund

1. böjningsform av hundur

## Isländska[redigera]

### Substantiv[redigera]

hund

1. böjningsform av hundur

## Nynorska[redigera]

### Substantiv[redigera]

Böjningar av hund | Singular | Plural
--- | --- | ---
maskulinum | Obestämd | Bestämd | Obestämd | Bestämd
Nominativ | hund | hunden | hundar | hundane

hund m

1. hund

## Vilamoviska[redigera]

### Substantiv[redigera]

hund m

- uttal: ⓘ

1. hund